==> tuia-advert-center-api-1.5.9-20180715.061021-3-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/RspAdvertTargetAppDetail.java <==
package cn.com.duiba.tuia.core.api.dto.rsp;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

public class RspAdvertTargetAppDetail implements Serializable{

	private static final long serialVersionUID = -3958085884450704418L;
	
	/**应用ID*/
    private Long appId;
    
    /**应用名称*/
    private String appName;

    private String tagName;
	
    /**所属账号*/
    private String appAccount;

    /**应用来源*/
    private Integer appSource;

	/**
	 * 应用状态
	 */
	private Integer appStatus;

	/**
	 * 广告位状态：1-不限 2-自定义
	 */
    private Integer soltStatus;

	/**
	 * 昨日CVR
	 */
	private Double yesterdayCVR;

	/**
	 * 昨日发券量
	 */
	private Long yesterLaunch;

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getAppAccount() {
		return appAccount;
	}

	public void setAppAccount(String appAccount) {
		this.appAccount = appAccount;
	}

	public Integer getAppSource() {
		return appSource;
	}

	public void setAppSource(Integer appSource) {
		this.appSource = appSource;
	}

	public String getTagName() {
		return tagName;
	}

	public void setTagName(String tagName) {
		this.tagName = tagName;
	}

	public Integer getAppStatus() {
		return appStatus;
	}

	public void setAppStatus(Integer appStatus) {
		this.appStatus = appStatus;
	}

	public Integer getSoltStatus() {
		return soltStatus;
	}

	public void setSoltStatus(Integer soltStatus) {
		this.soltStatus = soltStatus;
	}

	public Double getYesterdayCVR() {
		return yesterdayCVR;
	}

	public void setYesterdayCVR(Double yesterdayCVR) {
		this.yesterdayCVR = yesterdayCVR;
	}

	public Long getYesterLaunch() {
		return yesterLaunch;
	}

	public void setYesterLaunch(Long yesterLaunch) {
		this.yesterLaunch = yesterLaunch;
	}

	@Override
    public String toString() {
    	return ToStringBuilder.reflectionToString(this);
    }
}

==> tuia-advert-center-api-2.3.37-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/RspAdvertTargetAppDetail.java <==
package cn.com.duiba.tuia.core.api.dto.rsp;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

public class RspAdvertTargetAppDetail implements Serializable{

	private static final long serialVersionUID = -3958085884450704418L;

	/** 分媒体表中的id*/
	private Long id;
	
	/**应用ID*/
    private Long appId;
    
    /**应用名称*/
    private String appName;

    private String tagName;
	
    /**所属账号*/
    private String appAccount;

    /**应用来源*/
    private Integer appSource;

	//推荐类型,1-新媒体测试
	private Integer recommendType;

	/*
     * 1-完全屏蔽（广告行业、属性或落地页标签在对应应用的应用管理被屏蔽 || 所有广告位屏蔽状态为“是”）
     * 2-部分屏蔽（应用维度未屏蔽该广告，但部分广告位屏蔽状态为“是”）
     * 0-未屏蔽
     */
	private Integer shieldStatus;

	/**
	 * 应用状态
	 */
	private Integer appStatus;

	/**
	 * 广告位状态：1-不限 2-自定义
	 */
    private Integer soltStatus;

	/**
	 * 昨日CVR
	 */
	private Double yesterdayCVR;

	/**
	 * 昨日发券量
	 */
	private Long yesterLaunch;

	/**
	 * 潜力广告媒体建议出价
	 * @return
	 */
	private Long suggestFee;

	/**
	 * 潜力广告媒体cpc出价
	 * @return
	 */
	private Long cpcFee;

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Integer getShieldStatus() {
		return shieldStatus;
	}

	public void setShieldStatus(Integer shieldStatus) {
		this.shieldStatus = shieldStatus;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getAppAccount() {
		return appAccount;
	}

	public void setAppAccount(String appAccount) {
		this.appAccount = appAccount;
	}

	public Integer getAppSource() {
		return appSource;
	}

	public void setAppSource(Integer appSource) {
		this.appSource = appSource;
	}

	public String getTagName() {
		return tagName;
	}

	public void setTagName(String tagName) {
		this.tagName = tagName;
	}

	public Integer getRecommendType() {
		return recommendType;
	}

	public void setRecommendType(Integer recommendType) {
		this.recommendType = recommendType;
	}

	public Integer getAppStatus() {
		return appStatus;
	}

	public void setAppStatus(Integer appStatus) {
		this.appStatus = appStatus;
	}

	public Integer getSoltStatus() {
		return soltStatus;
	}

	public void setSoltStatus(Integer soltStatus) {
		this.soltStatus = soltStatus;
	}

	public Double getYesterdayCVR() {
		return yesterdayCVR;
	}

	public void setYesterdayCVR(Double yesterdayCVR) {
		this.yesterdayCVR = yesterdayCVR;
	}

	public Long getYesterLaunch() {
		return yesterLaunch;
	}

	public void setYesterLaunch(Long yesterLaunch) {
		this.yesterLaunch = yesterLaunch;
	}

	public Long getSuggestFee() {
		return suggestFee;
	}

	public void setSuggestFee(Long suggestFee) {
		this.suggestFee = suggestFee;
	}

	public Long getCpcFee() {
		return cpcFee;
	}

	public void setCpcFee(Long cpcFee) {
		this.cpcFee = cpcFee;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	@Override
    public String toString() {
    	return ToStringBuilder.reflectionToString(this);
    }
}
